==> openshift-model-operator-5.12.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConfigSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConfigSpecBuilder extends io.fabric8.openshift.api.model.operator.v1.ConfigSpecFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConfigSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.ConfigSpec,io.fabric8.openshift.api.model.operator.v1.ConfigSpecBuilder>{
  public ConfigSpecBuilder() {
    this(false);
  }
  public ConfigSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ConfigSpec(), validationEnabled);
  }
  public ConfigSpecBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigSpecBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConfigSpec(), validationEnabled);
  }
  public ConfigSpecBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ConfigSpec instance) {
    this(fluent, instance, false);
  }
  public ConfigSpecBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ConfigSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLogLevel(instance.getLogLevel()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withObservedConfig(instance.getObservedConfig()); 
    fluent.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    fluent.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigSpecBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigSpec instance) {
    this(instance,false);
  }
  public ConfigSpecBuilder(io.fabric8.openshift.api.model.operator.v1.ConfigSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLogLevel(instance.getLogLevel()); 
    this.withManagementState(instance.getManagementState()); 
    this.withObservedConfig(instance.getObservedConfig()); 
    this.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    this.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.ConfigSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.ConfigSpec build() {
    ConfigSpec buildable = new ConfigSpec(fluent.getLogLevel(),fluent.getManagementState(),fluent.getObservedConfig(),fluent.getOperatorLogLevel(),fluent.getUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConfigSpecBuilder that = (ConfigSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConfigSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConfigSpecBuilder extends ConfigSpecFluentImpl<ConfigSpecBuilder> implements VisitableBuilder<ConfigSpec,ConfigSpecBuilder>{
  public ConfigSpecBuilder() {
    this(false);
  }
  public ConfigSpecBuilder(Boolean validationEnabled) {
    this(new ConfigSpec(), validationEnabled);
  }
  public ConfigSpecBuilder(ConfigSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigSpecBuilder(ConfigSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConfigSpec(), validationEnabled);
  }
  public ConfigSpecBuilder(ConfigSpecFluent<?> fluent,ConfigSpec instance) {
    this(fluent, instance, false);
  }
  public ConfigSpecBuilder(ConfigSpecFluent<?> fluent,ConfigSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLogLevel(instance.getLogLevel()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withObservedConfig(instance.getObservedConfig()); 
    fluent.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    fluent.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigSpecBuilder(ConfigSpec instance) {
    this(instance,false);
  }
  public ConfigSpecBuilder(ConfigSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLogLevel(instance.getLogLevel()); 
    this.withManagementState(instance.getManagementState()); 
    this.withObservedConfig(instance.getObservedConfig()); 
    this.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    this.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConfigSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ConfigSpec build() {
    ConfigSpec buildable = new ConfigSpec(fluent.getLogLevel(),fluent.getManagementState(),fluent.getObservedConfig(),fluent.getOperatorLogLevel(),fluent.getUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
